# coding: utf-8

# flake8: noqa
"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

from __future__ import absolute_import

# import models into model package
from lightning_cloud.openapi.models.app_id_releases_body import AppIdReleasesBody
from lightning_cloud.openapi.models.appinstances_id_body import AppinstancesIdBody
from lightning_cloud.openapi.models.apps_id_body import AppsIdBody
from lightning_cloud.openapi.models.apps_id_body1 import AppsIdBody1
from lightning_cloud.openapi.models.appsv2_id_body import Appsv2IdBody
from lightning_cloud.openapi.models.billing_checkout_body import BillingCheckoutBody
from lightning_cloud.openapi.models.billing_checkout_body1 import BillingCheckoutBody1
from lightning_cloud.openapi.models.billing_subscription_body import BillingSubscriptionBody
from lightning_cloud.openapi.models.billing_transfer_body import BillingTransferBody
from lightning_cloud.openapi.models.billing_transfer_body1 import BillingTransferBody1
from lightning_cloud.openapi.models.cloudspace_id_metric_body import CloudspaceIdMetricBody
from lightning_cloud.openapi.models.cloudspace_id_runs_body import CloudspaceIdRunsBody
from lightning_cloud.openapi.models.cloudspaces_id_body import CloudspacesIdBody
from lightning_cloud.openapi.models.cluster_id_capacityreservations_body import ClusterIdCapacityreservationsBody
from lightning_cloud.openapi.models.clusters_id_body import ClustersIdBody
from lightning_cloud.openapi.models.clusters_id_body1 import ClustersIdBody1
from lightning_cloud.openapi.models.create import Create
from lightning_cloud.openapi.models.data_connection_mount_data_connection_mount_copy_status import DataConnectionMountDataConnectionMountCopyStatus
from lightning_cloud.openapi.models.datasets_id_body import DatasetsIdBody
from lightning_cloud.openapi.models.externalv1_cloud_space_instance_status import Externalv1CloudSpaceInstanceStatus
from lightning_cloud.openapi.models.externalv1_cluster import Externalv1Cluster
from lightning_cloud.openapi.models.externalv1_lightningapp_instance import Externalv1LightningappInstance
from lightning_cloud.openapi.models.externalv1_lightningwork import Externalv1Lightningwork
from lightning_cloud.openapi.models.externalv1_user_status import Externalv1UserStatus
from lightning_cloud.openapi.models.get_cluster_health_response_health_status import GetClusterHealthResponseHealthStatus
from lightning_cloud.openapi.models.id_action_body import IdActionBody
from lightning_cloud.openapi.models.id_artifacts_body import IdArtifactsBody
from lightning_cloud.openapi.models.id_codeconfig_body import IdCodeconfigBody
from lightning_cloud.openapi.models.id_collaborate_body import IdCollaborateBody
from lightning_cloud.openapi.models.id_engage_body import IdEngageBody
from lightning_cloud.openapi.models.id_execute_body import IdExecuteBody
from lightning_cloud.openapi.models.id_fork_body import IdForkBody
from lightning_cloud.openapi.models.id_get_body import IdGetBody
from lightning_cloud.openapi.models.id_get_body1 import IdGetBody1
from lightning_cloud.openapi.models.id_index_body import IdIndexBody
from lightning_cloud.openapi.models.id_index_body1 import IdIndexBody1
from lightning_cloud.openapi.models.id_multipartuploads_body import IdMultipartuploadsBody
from lightning_cloud.openapi.models.id_output_body import IdOutputBody
from lightning_cloud.openapi.models.id_publications_body import IdPublicationsBody
from lightning_cloud.openapi.models.id_release_body import IdReleaseBody
from lightning_cloud.openapi.models.id_uploads_body import IdUploadsBody
from lightning_cloud.openapi.models.instance_type_availability import InstanceTypeAvailability
from lightning_cloud.openapi.models.jobs_id_body import JobsIdBody
from lightning_cloud.openapi.models.jobs_id_body1 import JobsIdBody1
from lightning_cloud.openapi.models.litpages_id_body import LitpagesIdBody
from lightning_cloud.openapi.models.multipart_complete_body import MultipartCompleteBody
from lightning_cloud.openapi.models.multipartuploads_upload_id_body import MultipartuploadsUploadIdBody
from lightning_cloud.openapi.models.org_id_memberships_body import OrgIdMembershipsBody
from lightning_cloud.openapi.models.org_id_roles_body import OrgIdRolesBody
from lightning_cloud.openapi.models.orgs_id_body import OrgsIdBody
from lightning_cloud.openapi.models.project_id_appsv2_body import ProjectIdAppsv2Body
from lightning_cloud.openapi.models.project_id_cloudspaces_body import ProjectIdCloudspacesBody
from lightning_cloud.openapi.models.project_id_clusters_body import ProjectIdClustersBody
from lightning_cloud.openapi.models.project_id_datasets_body import ProjectIdDatasetsBody
from lightning_cloud.openapi.models.project_id_getapp_body import ProjectIdGetappBody
from lightning_cloud.openapi.models.project_id_invite_body import ProjectIdInviteBody
from lightning_cloud.openapi.models.project_id_memberships_body import ProjectIdMembershipsBody
from lightning_cloud.openapi.models.project_id_projectclustersbindings_body import ProjectIdProjectclustersbindingsBody
from lightning_cloud.openapi.models.project_id_secrets_body import ProjectIdSecretsBody
from lightning_cloud.openapi.models.project_id_storage_body import ProjectIdStorageBody
from lightning_cloud.openapi.models.projects_id_body import ProjectsIdBody
from lightning_cloud.openapi.models.projects_project_id_body import ProjectsProjectIdBody
from lightning_cloud.openapi.models.protobuf_any import ProtobufAny
from lightning_cloud.openapi.models.rpc_status import RpcStatus
from lightning_cloud.openapi.models.secrets_id_body import SecretsIdBody
from lightning_cloud.openapi.models.service_health_service_status import ServiceHealthServiceStatus
from lightning_cloud.openapi.models.slurm_jobs_body import SlurmJobsBody
from lightning_cloud.openapi.models.spec_lightningapp_instance_id_works_body import SpecLightningappInstanceIdWorksBody
from lightning_cloud.openapi.models.storage_complete_body import StorageCompleteBody
from lightning_cloud.openapi.models.storage_multipart_body import StorageMultipartBody
from lightning_cloud.openapi.models.studioapp_jobs_body import StudioappJobsBody
from lightning_cloud.openapi.models.subscription_checkout_body import SubscriptionCheckoutBody
from lightning_cloud.openapi.models.update import Update
from lightning_cloud.openapi.models.user_id_membershiprolebindings_body import UserIdMembershiprolebindingsBody
from lightning_cloud.openapi.models.user_id_membershiprolebindings_body1 import UserIdMembershiprolebindingsBody1
from lightning_cloud.openapi.models.v1_aws_cluster_credentials import V1AWSClusterCredentials
from lightning_cloud.openapi.models.v1_aws_cluster_driver_spec import V1AWSClusterDriverSpec
from lightning_cloud.openapi.models.v1_aws_cluster_secondary_region_spec import V1AWSClusterSecondaryRegionSpec
from lightning_cloud.openapi.models.v1_aws_direct_v1 import V1AWSDirectV1
from lightning_cloud.openapi.models.v1_aws_direct_v1_status import V1AWSDirectV1Status
from lightning_cloud.openapi.models.v1_agent_complete_part_response import V1AgentCompletePartResponse
from lightning_cloud.openapi.models.v1_agent_job import V1AgentJob
from lightning_cloud.openapi.models.v1_agent_job_artifact import V1AgentJobArtifact
from lightning_cloud.openapi.models.v1_agent_upload_multipart_url import V1AgentUploadMultipartUrl
from lightning_cloud.openapi.models.v1_agent_upload_part_response import V1AgentUploadPartResponse
from lightning_cloud.openapi.models.v1_artifact import V1Artifact
from lightning_cloud.openapi.models.v1_aws_data_connection import V1AwsDataConnection
from lightning_cloud.openapi.models.v1_azure_cluster_driver_spec import V1AzureClusterDriverSpec
from lightning_cloud.openapi.models.v1_azure_cluster_driver_status import V1AzureClusterDriverStatus
from lightning_cloud.openapi.models.v1_byom_cluster_driver import V1BYOMClusterDriver
from lightning_cloud.openapi.models.v1_billing_feature import V1BillingFeature
from lightning_cloud.openapi.models.v1_billing_subscription import V1BillingSubscription
from lightning_cloud.openapi.models.v1_build_spec import V1BuildSpec
from lightning_cloud.openapi.models.v1_cpu_system_metrics import V1CPUSystemMetrics
from lightning_cloud.openapi.models.v1_cancel_cloud_space_instance_switch_response import V1CancelCloudSpaceInstanceSwitchResponse
from lightning_cloud.openapi.models.v1_check_external_service_status_response import V1CheckExternalServiceStatusResponse
from lightning_cloud.openapi.models.v1_cloud_space import V1CloudSpace
from lightning_cloud.openapi.models.v1_cloud_space_app import V1CloudSpaceApp
from lightning_cloud.openapi.models.v1_cloud_space_app_action import V1CloudSpaceAppAction
from lightning_cloud.openapi.models.v1_cloud_space_app_action_type import V1CloudSpaceAppActionType
from lightning_cloud.openapi.models.v1_cloud_space_app_owner_type import V1CloudSpaceAppOwnerType
from lightning_cloud.openapi.models.v1_cloud_space_engagement_response import V1CloudSpaceEngagementResponse
from lightning_cloud.openapi.models.v1_cloud_space_id_list import V1CloudSpaceIdList
from lightning_cloud.openapi.models.v1_cloud_space_instance_collab_status import V1CloudSpaceInstanceCollabStatus
from lightning_cloud.openapi.models.v1_cloud_space_instance_config import V1CloudSpaceInstanceConfig
from lightning_cloud.openapi.models.v1_cloud_space_instance_startup_status import V1CloudSpaceInstanceStartupStatus
from lightning_cloud.openapi.models.v1_cloud_space_instance_state import V1CloudSpaceInstanceState
from lightning_cloud.openapi.models.v1_cloud_space_project_response import V1CloudSpaceProjectResponse
from lightning_cloud.openapi.models.v1_cloud_space_publication import V1CloudSpacePublication
from lightning_cloud.openapi.models.v1_cloud_space_publication_type import V1CloudSpacePublicationType
from lightning_cloud.openapi.models.v1_cloud_space_state import V1CloudSpaceState
from lightning_cloud.openapi.models.v1_cloud_space_tag import V1CloudSpaceTag
from lightning_cloud.openapi.models.v1_cluster_accelerator import V1ClusterAccelerator
from lightning_cloud.openapi.models.v1_cluster_capacity_reservation import V1ClusterCapacityReservation
from lightning_cloud.openapi.models.v1_cluster_deletion_options import V1ClusterDeletionOptions
from lightning_cloud.openapi.models.v1_cluster_driver import V1ClusterDriver
from lightning_cloud.openapi.models.v1_cluster_driver_status import V1ClusterDriverStatus
from lightning_cloud.openapi.models.v1_cluster_log_service import V1ClusterLogService
from lightning_cloud.openapi.models.v1_cluster_performance_profile import V1ClusterPerformanceProfile
from lightning_cloud.openapi.models.v1_cluster_spec import V1ClusterSpec
from lightning_cloud.openapi.models.v1_cluster_state import V1ClusterState
from lightning_cloud.openapi.models.v1_cluster_status import V1ClusterStatus
from lightning_cloud.openapi.models.v1_cluster_type import V1ClusterType
from lightning_cloud.openapi.models.v1_collab_action import V1CollabAction
from lightning_cloud.openapi.models.v1_collab_session import V1CollabSession
from lightning_cloud.openapi.models.v1_complete_agent_multipart_upload import V1CompleteAgentMultipartUpload
from lightning_cloud.openapi.models.v1_complete_multi_part_upload import V1CompleteMultiPartUpload
from lightning_cloud.openapi.models.v1_complete_multipart_upload_project_artifact_response import V1CompleteMultipartUploadProjectArtifactResponse
from lightning_cloud.openapi.models.v1_complete_onboarding_response import V1CompleteOnboardingResponse
from lightning_cloud.openapi.models.v1_complete_upload import V1CompleteUpload
from lightning_cloud.openapi.models.v1_complete_upload_project_artifact_response import V1CompleteUploadProjectArtifactResponse
from lightning_cloud.openapi.models.v1_compute_config import V1ComputeConfig
from lightning_cloud.openapi.models.v1_container_resources import V1ContainerResources
from lightning_cloud.openapi.models.v1_create_agent_multipart_upload_response import V1CreateAgentMultipartUploadResponse
from lightning_cloud.openapi.models.v1_create_checkout_session_response import V1CreateCheckoutSessionResponse
from lightning_cloud.openapi.models.v1_create_cloud_space_app_instance_response import V1CreateCloudSpaceAppInstanceResponse
from lightning_cloud.openapi.models.v1_create_cloud_space_instance_metric_response import V1CreateCloudSpaceInstanceMetricResponse
from lightning_cloud.openapi.models.v1_create_cluster_capacity_reservation_response import V1CreateClusterCapacityReservationResponse
from lightning_cloud.openapi.models.v1_create_cluster_request import V1CreateClusterRequest
from lightning_cloud.openapi.models.v1_create_cluster_response import V1CreateClusterResponse
from lightning_cloud.openapi.models.v1_create_lit_page_request import V1CreateLitPageRequest
from lightning_cloud.openapi.models.v1_create_lit_page_response import V1CreateLitPageResponse
from lightning_cloud.openapi.models.v1_create_multipart_upload_project_artifact_response import V1CreateMultipartUploadProjectArtifactResponse
from lightning_cloud.openapi.models.v1_create_organization_request import V1CreateOrganizationRequest
from lightning_cloud.openapi.models.v1_create_project_request import V1CreateProjectRequest
from lightning_cloud.openapi.models.v1_create_ssh_public_key_request import V1CreateSSHPublicKeyRequest
from lightning_cloud.openapi.models.v1_create_subscription_checkout_session_response import V1CreateSubscriptionCheckoutSessionResponse
from lightning_cloud.openapi.models.v1_data_connection import V1DataConnection
from lightning_cloud.openapi.models.v1_data_connection_artifact import V1DataConnectionArtifact
from lightning_cloud.openapi.models.v1_data_connection_mount import V1DataConnectionMount
from lightning_cloud.openapi.models.v1_dataset import V1Dataset
from lightning_cloud.openapi.models.v1_dataset_type import V1DatasetType
from lightning_cloud.openapi.models.v1_delete_cloud_space_app_response import V1DeleteCloudSpaceAppResponse
from lightning_cloud.openapi.models.v1_delete_cloud_space_response import V1DeleteCloudSpaceResponse
from lightning_cloud.openapi.models.v1_delete_cluster_capacity_reservation_response import V1DeleteClusterCapacityReservationResponse
from lightning_cloud.openapi.models.v1_delete_cluster_response import V1DeleteClusterResponse
from lightning_cloud.openapi.models.v1_delete_data_connection_response import V1DeleteDataConnectionResponse
from lightning_cloud.openapi.models.v1_delete_dataset_response import V1DeleteDatasetResponse
from lightning_cloud.openapi.models.v1_delete_lightning_run_response import V1DeleteLightningRunResponse
from lightning_cloud.openapi.models.v1_delete_lightningapp_instance_artifact_response import V1DeleteLightningappInstanceArtifactResponse
from lightning_cloud.openapi.models.v1_delete_lightningapp_instance_response import V1DeleteLightningappInstanceResponse
from lightning_cloud.openapi.models.v1_delete_lightningapp_release_response import V1DeleteLightningappReleaseResponse
from lightning_cloud.openapi.models.v1_delete_lightningapp_v2_response import V1DeleteLightningappV2Response
from lightning_cloud.openapi.models.v1_delete_lightningwork_response import V1DeleteLightningworkResponse
from lightning_cloud.openapi.models.v1_delete_lit_page_response import V1DeleteLitPageResponse
from lightning_cloud.openapi.models.v1_delete_model_response import V1DeleteModelResponse
from lightning_cloud.openapi.models.v1_delete_model_version_response import V1DeleteModelVersionResponse
from lightning_cloud.openapi.models.v1_delete_org_membership_response import V1DeleteOrgMembershipResponse
from lightning_cloud.openapi.models.v1_delete_org_membership_role_binding_response import V1DeleteOrgMembershipRoleBindingResponse
from lightning_cloud.openapi.models.v1_delete_org_role_response import V1DeleteOrgRoleResponse
from lightning_cloud.openapi.models.v1_delete_organization_response import V1DeleteOrganizationResponse
from lightning_cloud.openapi.models.v1_delete_project_artifact_response import V1DeleteProjectArtifactResponse
from lightning_cloud.openapi.models.v1_delete_project_cluster_binding_response import V1DeleteProjectClusterBindingResponse
from lightning_cloud.openapi.models.v1_delete_project_cluster_response import V1DeleteProjectClusterResponse
from lightning_cloud.openapi.models.v1_delete_project_membership_response import V1DeleteProjectMembershipResponse
from lightning_cloud.openapi.models.v1_delete_project_membership_role_binding_response import V1DeleteProjectMembershipRoleBindingResponse
from lightning_cloud.openapi.models.v1_delete_project_response import V1DeleteProjectResponse
from lightning_cloud.openapi.models.v1_delete_project_role_response import V1DeleteProjectRoleResponse
from lightning_cloud.openapi.models.v1_delete_ssh_public_key_response import V1DeleteSSHPublicKeyResponse
from lightning_cloud.openapi.models.v1_delete_secret_response import V1DeleteSecretResponse
from lightning_cloud.openapi.models.v1_delete_studio_job_response import V1DeleteStudioJobResponse
from lightning_cloud.openapi.models.v1_delete_user_slurm_job_response import V1DeleteUserSLURMJobResponse
from lightning_cloud.openapi.models.v1_dependency_cache_state import V1DependencyCacheState
from lightning_cloud.openapi.models.v1_dependency_file_info import V1DependencyFileInfo
from lightning_cloud.openapi.models.v1_download_lightningapp_instance_logs_response import V1DownloadLightningappInstanceLogsResponse
from lightning_cloud.openapi.models.v1_download_model_response import V1DownloadModelResponse
from lightning_cloud.openapi.models.v1_drive import V1Drive
from lightning_cloud.openapi.models.v1_drive_spec import V1DriveSpec
from lightning_cloud.openapi.models.v1_drive_state import V1DriveState
from lightning_cloud.openapi.models.v1_drive_state_reason import V1DriveStateReason
from lightning_cloud.openapi.models.v1_drive_status import V1DriveStatus
from lightning_cloud.openapi.models.v1_drive_type import V1DriveType
from lightning_cloud.openapi.models.v1_drive_type_spec import V1DriveTypeSpec
from lightning_cloud.openapi.models.v1_drive_type_status import V1DriveTypeStatus
from lightning_cloud.openapi.models.v1_eks_custer_driver_status import V1EKSCusterDriverStatus
from lightning_cloud.openapi.models.v1_env_var import V1EnvVar
from lightning_cloud.openapi.models.v1_execute_cloud_space_command_response import V1ExecuteCloudSpaceCommandResponse
from lightning_cloud.openapi.models.v1_external_kubeconfig import V1ExternalKubeconfig
from lightning_cloud.openapi.models.v1_flowserver import V1Flowserver
from lightning_cloud.openapi.models.v1_folder_index_status import V1FolderIndexStatus
from lightning_cloud.openapi.models.v1_gpu_system_metrics import V1GPUSystemMetrics
from lightning_cloud.openapi.models.v1_gallery_app import V1GalleryApp
from lightning_cloud.openapi.models.v1_gallery_component import V1GalleryComponent
from lightning_cloud.openapi.models.v1_gcp_data_connection import V1GcpDataConnection
from lightning_cloud.openapi.models.v1_generate_ssh_key_pair_request import V1GenerateSSHKeyPairRequest
from lightning_cloud.openapi.models.v1_get_agent_job_env_response import V1GetAgentJobEnvResponse
from lightning_cloud.openapi.models.v1_get_agent_job_logs_metadata_response import V1GetAgentJobLogsMetadataResponse
from lightning_cloud.openapi.models.v1_get_artifacts_page_response import V1GetArtifactsPageResponse
from lightning_cloud.openapi.models.v1_get_cloud_space_instance_status_response import V1GetCloudSpaceInstanceStatusResponse
from lightning_cloud.openapi.models.v1_get_cluster_credentials_response import V1GetClusterCredentialsResponse
from lightning_cloud.openapi.models.v1_get_cluster_health_response import V1GetClusterHealthResponse
from lightning_cloud.openapi.models.v1_get_cluster_response import V1GetClusterResponse
from lightning_cloud.openapi.models.v1_get_folder_index_response import V1GetFolderIndexResponse
from lightning_cloud.openapi.models.v1_get_lightning_run_source_code_download_url_response import V1GetLightningRunSourceCodeDownloadUrlResponse
from lightning_cloud.openapi.models.v1_get_lightningapp_instance_system_metrics_response import V1GetLightningappInstanceSystemMetricsResponse
from lightning_cloud.openapi.models.v1_get_lightningapp_source_code_download_url_response import V1GetLightningappSourceCodeDownloadUrlResponse
from lightning_cloud.openapi.models.v1_get_lit_page_response import V1GetLitPageResponse
from lightning_cloud.openapi.models.v1_get_project_balance_response import V1GetProjectBalanceResponse
from lightning_cloud.openapi.models.v1_get_project_compute_usage_response import V1GetProjectComputeUsageResponse
from lightning_cloud.openapi.models.v1_get_user_notification_preferences_response import V1GetUserNotificationPreferencesResponse
from lightning_cloud.openapi.models.v1_get_user_response import V1GetUserResponse
from lightning_cloud.openapi.models.v1_google_cloud_direct_v1 import V1GoogleCloudDirectV1
from lightning_cloud.openapi.models.v1_image_spec import V1ImageSpec
from lightning_cloud.openapi.models.v1_image_state import V1ImageState
from lightning_cloud.openapi.models.v1_index import V1Index
from lightning_cloud.openapi.models.v1_instance_overprovisioning_spec import V1InstanceOverprovisioningSpec
from lightning_cloud.openapi.models.v1_instance_spec import V1InstanceSpec
from lightning_cloud.openapi.models.v1_instance_type import V1InstanceType
from lightning_cloud.openapi.models.v1_invalidate_cloud_space_instance_code_settings_response import V1InvalidateCloudSpaceInstanceCodeSettingsResponse
from lightning_cloud.openapi.models.v1_invite_project_membership_response import V1InviteProjectMembershipResponse
from lightning_cloud.openapi.models.v1_job_action import V1JobAction
from lightning_cloud.openapi.models.v1_job_file import V1JobFile
from lightning_cloud.openapi.models.v1_keep_alive_cloud_space_instance_response import V1KeepAliveCloudSpaceInstanceResponse
from lightning_cloud.openapi.models.v1_kubernetes_cluster_driver import V1KubernetesClusterDriver
from lightning_cloud.openapi.models.v1_kubernetes_cluster_status import V1KubernetesClusterStatus
from lightning_cloud.openapi.models.v1_lightning_app_user import V1LightningAppUser
from lightning_cloud.openapi.models.v1_lightning_auth import V1LightningAuth
from lightning_cloud.openapi.models.v1_lightning_basic_auth import V1LightningBasicAuth
from lightning_cloud.openapi.models.v1_lightning_o_auth_auth import V1LightningOAuthAuth
from lightning_cloud.openapi.models.v1_lightning_run import V1LightningRun
from lightning_cloud.openapi.models.v1_lightningapp_cluster_driver import V1LightningappClusterDriver
from lightning_cloud.openapi.models.v1_lightningapp_instance_artifact import V1LightningappInstanceArtifact
from lightning_cloud.openapi.models.v1_lightningapp_instance_event import V1LightningappInstanceEvent
from lightning_cloud.openapi.models.v1_lightningapp_instance_spec import V1LightningappInstanceSpec
from lightning_cloud.openapi.models.v1_lightningapp_instance_state import V1LightningappInstanceState
from lightning_cloud.openapi.models.v1_lightningapp_instance_status import V1LightningappInstanceStatus
from lightning_cloud.openapi.models.v1_lightningapp_release import V1LightningappRelease
from lightning_cloud.openapi.models.v1_lightningapp_restart_policy import V1LightningappRestartPolicy
from lightning_cloud.openapi.models.v1_lightningapp_v2 import V1LightningappV2
from lightning_cloud.openapi.models.v1_lightningwork_cluster_driver import V1LightningworkClusterDriver
from lightning_cloud.openapi.models.v1_lightningwork_cost import V1LightningworkCost
from lightning_cloud.openapi.models.v1_lightningwork_drives import V1LightningworkDrives
from lightning_cloud.openapi.models.v1_lightningwork_event import V1LightningworkEvent
from lightning_cloud.openapi.models.v1_lightningwork_spec import V1LightningworkSpec
from lightning_cloud.openapi.models.v1_lightningwork_state import V1LightningworkState
from lightning_cloud.openapi.models.v1_lightningwork_status import V1LightningworkStatus
from lightning_cloud.openapi.models.v1_lightningwork_status_reason import V1LightningworkStatusReason
from lightning_cloud.openapi.models.v1_list_agent_job_artifacts_response import V1ListAgentJobArtifactsResponse
from lightning_cloud.openapi.models.v1_list_agent_jobs_response import V1ListAgentJobsResponse
from lightning_cloud.openapi.models.v1_list_cloud_space_apps_response import V1ListCloudSpaceAppsResponse
from lightning_cloud.openapi.models.v1_list_cloud_space_publications_response import V1ListCloudSpacePublicationsResponse
from lightning_cloud.openapi.models.v1_list_cloud_space_tags_response import V1ListCloudSpaceTagsResponse
from lightning_cloud.openapi.models.v1_list_cloud_spaces_response import V1ListCloudSpacesResponse
from lightning_cloud.openapi.models.v1_list_cluster_accelerators_response import V1ListClusterAcceleratorsResponse
from lightning_cloud.openapi.models.v1_list_cluster_capacity_reservations_response import V1ListClusterCapacityReservationsResponse
from lightning_cloud.openapi.models.v1_list_cluster_instance_types_response import V1ListClusterInstanceTypesResponse
from lightning_cloud.openapi.models.v1_list_clusters_response import V1ListClustersResponse
from lightning_cloud.openapi.models.v1_list_data_connection_artifacts_response import V1ListDataConnectionArtifactsResponse
from lightning_cloud.openapi.models.v1_list_data_connections_response import V1ListDataConnectionsResponse
from lightning_cloud.openapi.models.v1_list_datasets_response import V1ListDatasetsResponse
from lightning_cloud.openapi.models.v1_list_gallery_components_response import V1ListGalleryComponentsResponse
from lightning_cloud.openapi.models.v1_list_gallery_lightningapps_response import V1ListGalleryLightningappsResponse
from lightning_cloud.openapi.models.v1_list_job_files_response import V1ListJobFilesResponse
from lightning_cloud.openapi.models.v1_list_lightning_run_response import V1ListLightningRunResponse
from lightning_cloud.openapi.models.v1_list_lightningapp_instance_artifacts_response import V1ListLightningappInstanceArtifactsResponse
from lightning_cloud.openapi.models.v1_list_lightningapp_instance_events_response import V1ListLightningappInstanceEventsResponse
from lightning_cloud.openapi.models.v1_list_lightningapp_instances_response import V1ListLightningappInstancesResponse
from lightning_cloud.openapi.models.v1_list_lightningapps_v2_response import V1ListLightningappsV2Response
from lightning_cloud.openapi.models.v1_list_lightningwork_events_response import V1ListLightningworkEventsResponse
from lightning_cloud.openapi.models.v1_list_lightningwork_response import V1ListLightningworkResponse
from lightning_cloud.openapi.models.v1_list_lit_pages_response import V1ListLitPagesResponse
from lightning_cloud.openapi.models.v1_list_memberships_response import V1ListMembershipsResponse
from lightning_cloud.openapi.models.v1_list_model_versions_response import V1ListModelVersionsResponse
from lightning_cloud.openapi.models.v1_list_models_response import V1ListModelsResponse
from lightning_cloud.openapi.models.v1_list_org_members_response import V1ListOrgMembersResponse
from lightning_cloud.openapi.models.v1_list_org_membership_role_binding_response import V1ListOrgMembershipRoleBindingResponse
from lightning_cloud.openapi.models.v1_list_org_memberships_response import V1ListOrgMembershipsResponse
from lightning_cloud.openapi.models.v1_list_org_roles_response import V1ListOrgRolesResponse
from lightning_cloud.openapi.models.v1_list_organizations_response import V1ListOrganizationsResponse
from lightning_cloud.openapi.models.v1_list_project_artifacts_response import V1ListProjectArtifactsResponse
from lightning_cloud.openapi.models.v1_list_project_cluster_accelerators_response import V1ListProjectClusterAcceleratorsResponse
from lightning_cloud.openapi.models.v1_list_project_cluster_bindings_response import V1ListProjectClusterBindingsResponse
from lightning_cloud.openapi.models.v1_list_project_clusters_response import V1ListProjectClustersResponse
from lightning_cloud.openapi.models.v1_list_project_membership_role_binding_response import V1ListProjectMembershipRoleBindingResponse
from lightning_cloud.openapi.models.v1_list_project_memberships_response import V1ListProjectMembershipsResponse
from lightning_cloud.openapi.models.v1_list_project_roles_response import V1ListProjectRolesResponse
from lightning_cloud.openapi.models.v1_list_published_cloud_spaces_response import V1ListPublishedCloudSpacesResponse
from lightning_cloud.openapi.models.v1_list_ssh_public_keys_response import V1ListSSHPublicKeysResponse
from lightning_cloud.openapi.models.v1_list_secrets_response import V1ListSecretsResponse
from lightning_cloud.openapi.models.v1_list_studio_jobs_response import V1ListStudioJobsResponse
from lightning_cloud.openapi.models.v1_list_user_slurm_jobs_response import V1ListUserSLURMJobsResponse
from lightning_cloud.openapi.models.v1_lit_page import V1LitPage
from lightning_cloud.openapi.models.v1_lit_page_type import V1LitPageType
from lightning_cloud.openapi.models.v1_log_page import V1LogPage
from lightning_cloud.openapi.models.v1_login_request import V1LoginRequest
from lightning_cloud.openapi.models.v1_login_response import V1LoginResponse
from lightning_cloud.openapi.models.v1_logout_request import V1LogoutRequest
from lightning_cloud.openapi.models.v1_logout_response import V1LogoutResponse
from lightning_cloud.openapi.models.v1_logs_response import V1LogsResponse
from lightning_cloud.openapi.models.v1_magic_link_login_request import V1MagicLinkLoginRequest
from lightning_cloud.openapi.models.v1_magic_link_login_response import V1MagicLinkLoginResponse
from lightning_cloud.openapi.models.v1_membership import V1Membership
from lightning_cloud.openapi.models.v1_metadata import V1Metadata
from lightning_cloud.openapi.models.v1_model import V1Model
from lightning_cloud.openapi.models.v1_model_version_archive import V1ModelVersionArchive
from lightning_cloud.openapi.models.v1_multi_part_presigned_url import V1MultiPartPresignedUrl
from lightning_cloud.openapi.models.v1_network_config import V1NetworkConfig
from lightning_cloud.openapi.models.v1_notification_preference import V1NotificationPreference
from lightning_cloud.openapi.models.v1_notification_preferences_request import V1NotificationPreferencesRequest
from lightning_cloud.openapi.models.v1_notification_type import V1NotificationType
from lightning_cloud.openapi.models.v1_org_member import V1OrgMember
from lightning_cloud.openapi.models.v1_org_membership import V1OrgMembership
from lightning_cloud.openapi.models.v1_org_membership_role_binding import V1OrgMembershipRoleBinding
from lightning_cloud.openapi.models.v1_org_role import V1OrgRole
from lightning_cloud.openapi.models.v1_organization import V1Organization
from lightning_cloud.openapi.models.v1_owner_type import V1OwnerType
from lightning_cloud.openapi.models.v1_package_manager import V1PackageManager
from lightning_cloud.openapi.models.v1_plugin import V1Plugin
from lightning_cloud.openapi.models.v1_plugins_list_response import V1PluginsListResponse
from lightning_cloud.openapi.models.v1_presigned_url import V1PresignedUrl
from lightning_cloud.openapi.models.v1_project import V1Project
from lightning_cloud.openapi.models.v1_project_artifact import V1ProjectArtifact
from lightning_cloud.openapi.models.v1_project_cluster_binding import V1ProjectClusterBinding
from lightning_cloud.openapi.models.v1_project_compute_daily_usage import V1ProjectComputeDailyUsage
from lightning_cloud.openapi.models.v1_project_compute_usage import V1ProjectComputeUsage
from lightning_cloud.openapi.models.v1_project_membership import V1ProjectMembership
from lightning_cloud.openapi.models.v1_project_membership_invite import V1ProjectMembershipInvite
from lightning_cloud.openapi.models.v1_project_membership_role_binding import V1ProjectMembershipRoleBinding
from lightning_cloud.openapi.models.v1_project_settings import V1ProjectSettings
from lightning_cloud.openapi.models.v1_publish_cloud_space_response import V1PublishCloudSpaceResponse
from lightning_cloud.openapi.models.v1_published_cloud_space_response import V1PublishedCloudSpaceResponse
from lightning_cloud.openapi.models.v1_python_dependency_info import V1PythonDependencyInfo
from lightning_cloud.openapi.models.v1_queue_server_type import V1QueueServerType
from lightning_cloud.openapi.models.v1_quotas import V1Quotas
from lightning_cloud.openapi.models.v1_quote_subscription_response import V1QuoteSubscriptionResponse
from lightning_cloud.openapi.models.v1_refresh_index_response import V1RefreshIndexResponse
from lightning_cloud.openapi.models.v1_refresh_request import V1RefreshRequest
from lightning_cloud.openapi.models.v1_refresh_response import V1RefreshResponse
from lightning_cloud.openapi.models.v1_region_state import V1RegionState
from lightning_cloud.openapi.models.v1_request_verification_code_response import V1RequestVerificationCodeResponse
from lightning_cloud.openapi.models.v1_resources import V1Resources
from lightning_cloud.openapi.models.v1_restart_cloud_space_instance_response import V1RestartCloudSpaceInstanceResponse
from lightning_cloud.openapi.models.v1_role import V1Role
from lightning_cloud.openapi.models.v1_rule import V1Rule
from lightning_cloud.openapi.models.v1_rule_action import V1RuleAction
from lightning_cloud.openapi.models.v1_rule_effect import V1RuleEffect
from lightning_cloud.openapi.models.v1_rule_resource import V1RuleResource
from lightning_cloud.openapi.models.v1_slurm_job import V1SLURMJob
from lightning_cloud.openapi.models.v1_ssh_key_pair import V1SSHKeyPair
from lightning_cloud.openapi.models.v1_ssh_public_key import V1SSHPublicKey
from lightning_cloud.openapi.models.v1_search_user import V1SearchUser
from lightning_cloud.openapi.models.v1_search_users_response import V1SearchUsersResponse
from lightning_cloud.openapi.models.v1_secret import V1Secret
from lightning_cloud.openapi.models.v1_service_health import V1ServiceHealth
from lightning_cloud.openapi.models.v1_setup_confirmed_ssh_public_key_response import V1SetupConfirmedSSHPublicKeyResponse
from lightning_cloud.openapi.models.v1_slurm_node import V1SlurmNode
from lightning_cloud.openapi.models.v1_slurm_v1 import V1SlurmV1
from lightning_cloud.openapi.models.v1_slurm_v1_job_status import V1SlurmV1JobStatus
from lightning_cloud.openapi.models.v1_slurm_v1_status import V1SlurmV1Status
from lightning_cloud.openapi.models.v1_source_type import V1SourceType
from lightning_cloud.openapi.models.v1_start_cloud_space_instance_response import V1StartCloudSpaceInstanceResponse
from lightning_cloud.openapi.models.v1_stop_cloud_space_instance_response import V1StopCloudSpaceInstanceResponse
from lightning_cloud.openapi.models.v1_stop_studio_job_response import V1StopStudioJobResponse
from lightning_cloud.openapi.models.v1_storage_system_metrics import V1StorageSystemMetrics
from lightning_cloud.openapi.models.v1_studio_job import V1StudioJob
from lightning_cloud.openapi.models.v1_studio_job_app import V1StudioJobApp
from lightning_cloud.openapi.models.v1_switch_cloud_space_instance_response import V1SwitchCloudSpaceInstanceResponse
from lightning_cloud.openapi.models.v1_system_metrics import V1SystemMetrics
from lightning_cloud.openapi.models.v1_system_metrics_list import V1SystemMetricsList
from lightning_cloud.openapi.models.v1_top_up import V1TopUp
from lightning_cloud.openapi.models.v1_transfer import V1Transfer
from lightning_cloud.openapi.models.v1_transfer_org_balance_response import V1TransferOrgBalanceResponse
from lightning_cloud.openapi.models.v1_transfer_project_balance_response import V1TransferProjectBalanceResponse
from lightning_cloud.openapi.models.v1_unpublish_cloud_space_response import V1UnpublishCloudSpaceResponse
from lightning_cloud.openapi.models.v1_update_agent_status_request import V1UpdateAgentStatusRequest
from lightning_cloud.openapi.models.v1_update_agent_status_response import V1UpdateAgentStatusResponse
from lightning_cloud.openapi.models.v1_update_cloud_space_collab_response import V1UpdateCloudSpaceCollabResponse
from lightning_cloud.openapi.models.v1_update_cluster_accelerators_response import V1UpdateClusterAcceleratorsResponse
from lightning_cloud.openapi.models.v1_update_cluster_response import V1UpdateClusterResponse
from lightning_cloud.openapi.models.v1_update_lit_page_response import V1UpdateLitPageResponse
from lightning_cloud.openapi.models.v1_update_project_cluster_accelerators_response import V1UpdateProjectClusterAcceleratorsResponse
from lightning_cloud.openapi.models.v1_update_user_request import V1UpdateUserRequest
from lightning_cloud.openapi.models.v1_upload_agent_job_artifact_response import V1UploadAgentJobArtifactResponse
from lightning_cloud.openapi.models.v1_upload_agent_job_output_response import V1UploadAgentJobOutputResponse
from lightning_cloud.openapi.models.v1_upload_lightningapp_instance_artifact_response import V1UploadLightningappInstanceArtifactResponse
from lightning_cloud.openapi.models.v1_upload_model_request import V1UploadModelRequest
from lightning_cloud.openapi.models.v1_upload_model_response import V1UploadModelResponse
from lightning_cloud.openapi.models.v1_upload_project_artifact_response import V1UploadProjectArtifactResponse
from lightning_cloud.openapi.models.v1_usage import V1Usage
from lightning_cloud.openapi.models.v1_usage_details import V1UsageDetails
from lightning_cloud.openapi.models.v1_usage_report import V1UsageReport
from lightning_cloud.openapi.models.v1_user_features import V1UserFeatures
from lightning_cloud.openapi.models.v1_user_requested_compute_config import V1UserRequestedComputeConfig
from lightning_cloud.openapi.models.v1_user_requested_flow_compute_config import V1UserRequestedFlowComputeConfig
from lightning_cloud.openapi.models.v1_user_slurm_job_action_response import V1UserSLURMJobActionResponse
from lightning_cloud.openapi.models.v1_validate_data_connection_response import V1ValidateDataConnectionResponse
from lightning_cloud.openapi.models.v1_verify_verification_response import V1VerifyVerificationResponse
from lightning_cloud.openapi.models.v1_work import V1Work
from lightning_cloud.openapi.models.validate import Validate
from lightning_cloud.openapi.models.works_id_body import WorksIdBody



# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401

from typing import TYPE_CHECKING

import six

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class V1UserRequestedComputeConfig(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'affinity_identifier': 'str',
        'count': 'int',
        'cpu_image_override': 'str',
        'disk_size': 'int',
        'gpu_image_override': 'str',
        'id': 'str',
        'is_byom': 'bool',
        'name': 'str',
        'preemptible': 'bool',
        'same_compute_on_resume': 'bool',
        'shm_size': 'int'
    }

    attribute_map = {
        'affinity_identifier': 'affinityIdentifier',
        'count': 'count',
        'cpu_image_override': 'cpuImageOverride',
        'disk_size': 'diskSize',
        'gpu_image_override': 'gpuImageOverride',
        'id': 'id',
        'is_byom': 'isByom',
        'name': 'name',
        'preemptible': 'preemptible',
        'same_compute_on_resume': 'sameComputeOnResume',
        'shm_size': 'shmSize'
    }

    def __init__(self, affinity_identifier: 'str' =None, count: 'int' =None, cpu_image_override: 'str' =None, disk_size: 'int' =None, gpu_image_override: 'str' =None, id: 'str' =None, is_byom: 'bool' =None, name: 'str' =None, preemptible: 'bool' =None, same_compute_on_resume: 'bool' =None, shm_size: 'int' =None):  # noqa: E501
        """V1UserRequestedComputeConfig - a model defined in Swagger"""  # noqa: E501
        self._affinity_identifier = None
        self._count = None
        self._cpu_image_override = None
        self._disk_size = None
        self._gpu_image_override = None
        self._id = None
        self._is_byom = None
        self._name = None
        self._preemptible = None
        self._same_compute_on_resume = None
        self._shm_size = None
        self.discriminator = None
        if affinity_identifier is not None:
            self.affinity_identifier = affinity_identifier
        if count is not None:
            self.count = count
        if cpu_image_override is not None:
            self.cpu_image_override = cpu_image_override
        if disk_size is not None:
            self.disk_size = disk_size
        if gpu_image_override is not None:
            self.gpu_image_override = gpu_image_override
        if id is not None:
            self.id = id
        if is_byom is not None:
            self.is_byom = is_byom
        if name is not None:
            self.name = name
        if preemptible is not None:
            self.preemptible = preemptible
        if same_compute_on_resume is not None:
            self.same_compute_on_resume = same_compute_on_resume
        if shm_size is not None:
            self.shm_size = shm_size

    @property
    def affinity_identifier(self) -> 'str':
        """Gets the affinity_identifier of this V1UserRequestedComputeConfig.  # noqa: E501

        affinity_identifier is an arbitrary value that is used to co-located different works in the same zone.  # noqa: E501

        :return: The affinity_identifier of this V1UserRequestedComputeConfig.  # noqa: E501
        :rtype: str
        """
        return self._affinity_identifier

    @affinity_identifier.setter
    def affinity_identifier(self, affinity_identifier: 'str'):
        """Sets the affinity_identifier of this V1UserRequestedComputeConfig.

        affinity_identifier is an arbitrary value that is used to co-located different works in the same zone.  # noqa: E501

        :param affinity_identifier: The affinity_identifier of this V1UserRequestedComputeConfig.  # noqa: E501
        :type: str
        """

        self._affinity_identifier = affinity_identifier

    @property
    def count(self) -> 'int':
        """Gets the count of this V1UserRequestedComputeConfig.  # noqa: E501


        :return: The count of this V1UserRequestedComputeConfig.  # noqa: E501
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count: 'int'):
        """Sets the count of this V1UserRequestedComputeConfig.


        :param count: The count of this V1UserRequestedComputeConfig.  # noqa: E501
        :type: int
        """

        self._count = count

    @property
    def cpu_image_override(self) -> 'str':
        """Gets the cpu_image_override of this V1UserRequestedComputeConfig.  # noqa: E501

        cpu_image_override is used to specify a custom image used to launch the resource when running on a cpu machine.  # noqa: E501

        :return: The cpu_image_override of this V1UserRequestedComputeConfig.  # noqa: E501
        :rtype: str
        """
        return self._cpu_image_override

    @cpu_image_override.setter
    def cpu_image_override(self, cpu_image_override: 'str'):
        """Sets the cpu_image_override of this V1UserRequestedComputeConfig.

        cpu_image_override is used to specify a custom image used to launch the resource when running on a cpu machine.  # noqa: E501

        :param cpu_image_override: The cpu_image_override of this V1UserRequestedComputeConfig.  # noqa: E501
        :type: str
        """

        self._cpu_image_override = cpu_image_override

    @property
    def disk_size(self) -> 'int':
        """Gets the disk_size of this V1UserRequestedComputeConfig.  # noqa: E501


        :return: The disk_size of this V1UserRequestedComputeConfig.  # noqa: E501
        :rtype: int
        """
        return self._disk_size

    @disk_size.setter
    def disk_size(self, disk_size: 'int'):
        """Sets the disk_size of this V1UserRequestedComputeConfig.


        :param disk_size: The disk_size of this V1UserRequestedComputeConfig.  # noqa: E501
        :type: int
        """

        self._disk_size = disk_size

    @property
    def gpu_image_override(self) -> 'str':
        """Gets the gpu_image_override of this V1UserRequestedComputeConfig.  # noqa: E501

        gpu_image_override is used to specify a custom image used to launch the resource when running on a cpu machine.  # noqa: E501

        :return: The gpu_image_override of this V1UserRequestedComputeConfig.  # noqa: E501
        :rtype: str
        """
        return self._gpu_image_override

    @gpu_image_override.setter
    def gpu_image_override(self, gpu_image_override: 'str'):
        """Sets the gpu_image_override of this V1UserRequestedComputeConfig.

        gpu_image_override is used to specify a custom image used to launch the resource when running on a cpu machine.  # noqa: E501

        :param gpu_image_override: The gpu_image_override of this V1UserRequestedComputeConfig.  # noqa: E501
        :type: str
        """

        self._gpu_image_override = gpu_image_override

    @property
    def id(self) -> 'str':
        """Gets the id of this V1UserRequestedComputeConfig.  # noqa: E501


        :return: The id of this V1UserRequestedComputeConfig.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id: 'str'):
        """Sets the id of this V1UserRequestedComputeConfig.


        :param id: The id of this V1UserRequestedComputeConfig.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def is_byom(self) -> 'bool':
        """Gets the is_byom of this V1UserRequestedComputeConfig.  # noqa: E501


        :return: The is_byom of this V1UserRequestedComputeConfig.  # noqa: E501
        :rtype: bool
        """
        return self._is_byom

    @is_byom.setter
    def is_byom(self, is_byom: 'bool'):
        """Sets the is_byom of this V1UserRequestedComputeConfig.


        :param is_byom: The is_byom of this V1UserRequestedComputeConfig.  # noqa: E501
        :type: bool
        """

        self._is_byom = is_byom

    @property
    def name(self) -> 'str':
        """Gets the name of this V1UserRequestedComputeConfig.  # noqa: E501


        :return: The name of this V1UserRequestedComputeConfig.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name: 'str'):
        """Sets the name of this V1UserRequestedComputeConfig.


        :param name: The name of this V1UserRequestedComputeConfig.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def preemptible(self) -> 'bool':
        """Gets the preemptible of this V1UserRequestedComputeConfig.  # noqa: E501


        :return: The preemptible of this V1UserRequestedComputeConfig.  # noqa: E501
        :rtype: bool
        """
        return self._preemptible

    @preemptible.setter
    def preemptible(self, preemptible: 'bool'):
        """Sets the preemptible of this V1UserRequestedComputeConfig.


        :param preemptible: The preemptible of this V1UserRequestedComputeConfig.  # noqa: E501
        :type: bool
        """

        self._preemptible = preemptible

    @property
    def same_compute_on_resume(self) -> 'bool':
        """Gets the same_compute_on_resume of this V1UserRequestedComputeConfig.  # noqa: E501


        :return: The same_compute_on_resume of this V1UserRequestedComputeConfig.  # noqa: E501
        :rtype: bool
        """
        return self._same_compute_on_resume

    @same_compute_on_resume.setter
    def same_compute_on_resume(self, same_compute_on_resume: 'bool'):
        """Sets the same_compute_on_resume of this V1UserRequestedComputeConfig.


        :param same_compute_on_resume: The same_compute_on_resume of this V1UserRequestedComputeConfig.  # noqa: E501
        :type: bool
        """

        self._same_compute_on_resume = same_compute_on_resume

    @property
    def shm_size(self) -> 'int':
        """Gets the shm_size of this V1UserRequestedComputeConfig.  # noqa: E501


        :return: The shm_size of this V1UserRequestedComputeConfig.  # noqa: E501
        :rtype: int
        """
        return self._shm_size

    @shm_size.setter
    def shm_size(self, shm_size: 'int'):
        """Sets the shm_size of this V1UserRequestedComputeConfig.


        :param shm_size: The shm_size of this V1UserRequestedComputeConfig.  # noqa: E501
        :type: int
        """

        self._shm_size = shm_size

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1UserRequestedComputeConfig, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'V1UserRequestedComputeConfig') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, V1UserRequestedComputeConfig):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other: 'V1UserRequestedComputeConfig') -> bool:
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401

from typing import TYPE_CHECKING

import six

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class V1GetUserResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'agree_to_terms_and_conditions': 'bool',
        'api_key': 'str',
        'country': 'str',
        'email': 'str',
        'features': 'V1UserFeatures',
        'first_name': 'str',
        'general_audience_mode': 'bool',
        'id': 'str',
        'internal_docs_admin': 'bool',
        'is_internal': 'bool',
        'last_name': 'str',
        'opted_in_marketing_emails': 'bool',
        'organization': 'str',
        'organizations': 'list[V1Organization]',
        'picture_url': 'str',
        'preferred_color_scheme': 'str',
        'preferred_ide': 'str',
        'preferred_vscode_marketplace': 'str',
        'role': 'str',
        'saw_create_first_project_dialog': 'bool',
        'saw_forums_login_merge_dialog': 'bool',
        'saw_free_credits_notification': 'bool',
        'status': 'Externalv1UserStatus',
        'user_metadata': 'str',
        'username': 'str',
        'waitlisted': 'bool',
        'website': 'str'
    }

    attribute_map = {
        'agree_to_terms_and_conditions': 'agreeToTermsAndConditions',
        'api_key': 'apiKey',
        'country': 'country',
        'email': 'email',
        'features': 'features',
        'first_name': 'firstName',
        'general_audience_mode': 'generalAudienceMode',
        'id': 'id',
        'internal_docs_admin': 'internalDocsAdmin',
        'is_internal': 'isInternal',
        'last_name': 'lastName',
        'opted_in_marketing_emails': 'optedInMarketingEmails',
        'organization': 'organization',
        'organizations': 'organizations',
        'picture_url': 'pictureUrl',
        'preferred_color_scheme': 'preferredColorScheme',
        'preferred_ide': 'preferredIde',
        'preferred_vscode_marketplace': 'preferredVscodeMarketplace',
        'role': 'role',
        'saw_create_first_project_dialog': 'sawCreateFirstProjectDialog',
        'saw_forums_login_merge_dialog': 'sawForumsLoginMergeDialog',
        'saw_free_credits_notification': 'sawFreeCreditsNotification',
        'status': 'status',
        'user_metadata': 'userMetadata',
        'username': 'username',
        'waitlisted': 'waitlisted',
        'website': 'website'
    }

    def __init__(self, agree_to_terms_and_conditions: 'bool' =None, api_key: 'str' =None, country: 'str' =None, email: 'str' =None, features: 'V1UserFeatures' =None, first_name: 'str' =None, general_audience_mode: 'bool' =None, id: 'str' =None, internal_docs_admin: 'bool' =None, is_internal: 'bool' =None, last_name: 'str' =None, opted_in_marketing_emails: 'bool' =None, organization: 'str' =None, organizations: 'list[V1Organization]' =None, picture_url: 'str' =None, preferred_color_scheme: 'str' =None, preferred_ide: 'str' =None, preferred_vscode_marketplace: 'str' =None, role: 'str' =None, saw_create_first_project_dialog: 'bool' =None, saw_forums_login_merge_dialog: 'bool' =None, saw_free_credits_notification: 'bool' =None, status: 'Externalv1UserStatus' =None, user_metadata: 'str' =None, username: 'str' =None, waitlisted: 'bool' =None, website: 'str' =None):  # noqa: E501
        """V1GetUserResponse - a model defined in Swagger"""  # noqa: E501
        self._agree_to_terms_and_conditions = None
        self._api_key = None
        self._country = None
        self._email = None
        self._features = None
        self._first_name = None
        self._general_audience_mode = None
        self._id = None
        self._internal_docs_admin = None
        self._is_internal = None
        self._last_name = None
        self._opted_in_marketing_emails = None
        self._organization = None
        self._organizations = None
        self._picture_url = None
        self._preferred_color_scheme = None
        self._preferred_ide = None
        self._preferred_vscode_marketplace = None
        self._role = None
        self._saw_create_first_project_dialog = None
        self._saw_forums_login_merge_dialog = None
        self._saw_free_credits_notification = None
        self._status = None
        self._user_metadata = None
        self._username = None
        self._waitlisted = None
        self._website = None
        self.discriminator = None
        if agree_to_terms_and_conditions is not None:
            self.agree_to_terms_and_conditions = agree_to_terms_and_conditions
        if api_key is not None:
            self.api_key = api_key
        if country is not None:
            self.country = country
        if email is not None:
            self.email = email
        if features is not None:
            self.features = features
        if first_name is not None:
            self.first_name = first_name
        if general_audience_mode is not None:
            self.general_audience_mode = general_audience_mode
        if id is not None:
            self.id = id
        if internal_docs_admin is not None:
            self.internal_docs_admin = internal_docs_admin
        if is_internal is not None:
            self.is_internal = is_internal
        if last_name is not None:
            self.last_name = last_name
        if opted_in_marketing_emails is not None:
            self.opted_in_marketing_emails = opted_in_marketing_emails
        if organization is not None:
            self.organization = organization
        if organizations is not None:
            self.organizations = organizations
        if picture_url is not None:
            self.picture_url = picture_url
        if preferred_color_scheme is not None:
            self.preferred_color_scheme = preferred_color_scheme
        if preferred_ide is not None:
            self.preferred_ide = preferred_ide
        if preferred_vscode_marketplace is not None:
            self.preferred_vscode_marketplace = preferred_vscode_marketplace
        if role is not None:
            self.role = role
        if saw_create_first_project_dialog is not None:
            self.saw_create_first_project_dialog = saw_create_first_project_dialog
        if saw_forums_login_merge_dialog is not None:
            self.saw_forums_login_merge_dialog = saw_forums_login_merge_dialog
        if saw_free_credits_notification is not None:
            self.saw_free_credits_notification = saw_free_credits_notification
        if status is not None:
            self.status = status
        if user_metadata is not None:
            self.user_metadata = user_metadata
        if username is not None:
            self.username = username
        if waitlisted is not None:
            self.waitlisted = waitlisted
        if website is not None:
            self.website = website

    @property
    def agree_to_terms_and_conditions(self) -> 'bool':
        """Gets the agree_to_terms_and_conditions of this V1GetUserResponse.  # noqa: E501


        :return: The agree_to_terms_and_conditions of this V1GetUserResponse.  # noqa: E501
        :rtype: bool
        """
        return self._agree_to_terms_and_conditions

    @agree_to_terms_and_conditions.setter
    def agree_to_terms_and_conditions(self, agree_to_terms_and_conditions: 'bool'):
        """Sets the agree_to_terms_and_conditions of this V1GetUserResponse.


        :param agree_to_terms_and_conditions: The agree_to_terms_and_conditions of this V1GetUserResponse.  # noqa: E501
        :type: bool
        """

        self._agree_to_terms_and_conditions = agree_to_terms_and_conditions

    @property
    def api_key(self) -> 'str':
        """Gets the api_key of this V1GetUserResponse.  # noqa: E501


        :return: The api_key of this V1GetUserResponse.  # noqa: E501
        :rtype: str
        """
        return self._api_key

    @api_key.setter
    def api_key(self, api_key: 'str'):
        """Sets the api_key of this V1GetUserResponse.


        :param api_key: The api_key of this V1GetUserResponse.  # noqa: E501
        :type: str
        """

        self._api_key = api_key

    @property
    def country(self) -> 'str':
        """Gets the country of this V1GetUserResponse.  # noqa: E501


        :return: The country of this V1GetUserResponse.  # noqa: E501
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country: 'str'):
        """Sets the country of this V1GetUserResponse.


        :param country: The country of this V1GetUserResponse.  # noqa: E501
        :type: str
        """

        self._country = country

    @property
    def email(self) -> 'str':
        """Gets the email of this V1GetUserResponse.  # noqa: E501


        :return: The email of this V1GetUserResponse.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email: 'str'):
        """Sets the email of this V1GetUserResponse.


        :param email: The email of this V1GetUserResponse.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def features(self) -> 'V1UserFeatures':
        """Gets the features of this V1GetUserResponse.  # noqa: E501


        :return: The features of this V1GetUserResponse.  # noqa: E501
        :rtype: V1UserFeatures
        """
        return self._features

    @features.setter
    def features(self, features: 'V1UserFeatures'):
        """Sets the features of this V1GetUserResponse.


        :param features: The features of this V1GetUserResponse.  # noqa: E501
        :type: V1UserFeatures
        """

        self._features = features

    @property
    def first_name(self) -> 'str':
        """Gets the first_name of this V1GetUserResponse.  # noqa: E501


        :return: The first_name of this V1GetUserResponse.  # noqa: E501
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name: 'str'):
        """Sets the first_name of this V1GetUserResponse.


        :param first_name: The first_name of this V1GetUserResponse.  # noqa: E501
        :type: str
        """

        self._first_name = first_name

    @property
    def general_audience_mode(self) -> 'bool':
        """Gets the general_audience_mode of this V1GetUserResponse.  # noqa: E501


        :return: The general_audience_mode of this V1GetUserResponse.  # noqa: E501
        :rtype: bool
        """
        return self._general_audience_mode

    @general_audience_mode.setter
    def general_audience_mode(self, general_audience_mode: 'bool'):
        """Sets the general_audience_mode of this V1GetUserResponse.


        :param general_audience_mode: The general_audience_mode of this V1GetUserResponse.  # noqa: E501
        :type: bool
        """

        self._general_audience_mode = general_audience_mode

    @property
    def id(self) -> 'str':
        """Gets the id of this V1GetUserResponse.  # noqa: E501


        :return: The id of this V1GetUserResponse.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id: 'str'):
        """Sets the id of this V1GetUserResponse.


        :param id: The id of this V1GetUserResponse.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def internal_docs_admin(self) -> 'bool':
        """Gets the internal_docs_admin of this V1GetUserResponse.  # noqa: E501


        :return: The internal_docs_admin of this V1GetUserResponse.  # noqa: E501
        :rtype: bool
        """
        return self._internal_docs_admin

    @internal_docs_admin.setter
    def internal_docs_admin(self, internal_docs_admin: 'bool'):
        """Sets the internal_docs_admin of this V1GetUserResponse.


        :param internal_docs_admin: The internal_docs_admin of this V1GetUserResponse.  # noqa: E501
        :type: bool
        """

        self._internal_docs_admin = internal_docs_admin

    @property
    def is_internal(self) -> 'bool':
        """Gets the is_internal of this V1GetUserResponse.  # noqa: E501


        :return: The is_internal of this V1GetUserResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_internal

    @is_internal.setter
    def is_internal(self, is_internal: 'bool'):
        """Sets the is_internal of this V1GetUserResponse.


        :param is_internal: The is_internal of this V1GetUserResponse.  # noqa: E501
        :type: bool
        """

        self._is_internal = is_internal

    @property
    def last_name(self) -> 'str':
        """Gets the last_name of this V1GetUserResponse.  # noqa: E501


        :return: The last_name of this V1GetUserResponse.  # noqa: E501
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name: 'str'):
        """Sets the last_name of this V1GetUserResponse.


        :param last_name: The last_name of this V1GetUserResponse.  # noqa: E501
        :type: str
        """

        self._last_name = last_name

    @property
    def opted_in_marketing_emails(self) -> 'bool':
        """Gets the opted_in_marketing_emails of this V1GetUserResponse.  # noqa: E501


        :return: The opted_in_marketing_emails of this V1GetUserResponse.  # noqa: E501
        :rtype: bool
        """
        return self._opted_in_marketing_emails

    @opted_in_marketing_emails.setter
    def opted_in_marketing_emails(self, opted_in_marketing_emails: 'bool'):
        """Sets the opted_in_marketing_emails of this V1GetUserResponse.


        :param opted_in_marketing_emails: The opted_in_marketing_emails of this V1GetUserResponse.  # noqa: E501
        :type: bool
        """

        self._opted_in_marketing_emails = opted_in_marketing_emails

    @property
    def organization(self) -> 'str':
        """Gets the organization of this V1GetUserResponse.  # noqa: E501


        :return: The organization of this V1GetUserResponse.  # noqa: E501
        :rtype: str
        """
        return self._organization

    @organization.setter
    def organization(self, organization: 'str'):
        """Sets the organization of this V1GetUserResponse.


        :param organization: The organization of this V1GetUserResponse.  # noqa: E501
        :type: str
        """

        self._organization = organization

    @property
    def organizations(self) -> 'list[V1Organization]':
        """Gets the organizations of this V1GetUserResponse.  # noqa: E501


        :return: The organizations of this V1GetUserResponse.  # noqa: E501
        :rtype: list[V1Organization]
        """
        return self._organizations

    @organizations.setter
    def organizations(self, organizations: 'list[V1Organization]'):
        """Sets the organizations of this V1GetUserResponse.


        :param organizations: The organizations of this V1GetUserResponse.  # noqa: E501
        :type: list[V1Organization]
        """

        self._organizations = organizations

    @property
    def picture_url(self) -> 'str':
        """Gets the picture_url of this V1GetUserResponse.  # noqa: E501


        :return: The picture_url of this V1GetUserResponse.  # noqa: E501
        :rtype: str
        """
        return self._picture_url

    @picture_url.setter
    def picture_url(self, picture_url: 'str'):
        """Sets the picture_url of this V1GetUserResponse.


        :param picture_url: The picture_url of this V1GetUserResponse.  # noqa: E501
        :type: str
        """

        self._picture_url = picture_url

    @property
    def preferred_color_scheme(self) -> 'str':
        """Gets the preferred_color_scheme of this V1GetUserResponse.  # noqa: E501


        :return: The preferred_color_scheme of this V1GetUserResponse.  # noqa: E501
        :rtype: str
        """
        return self._preferred_color_scheme

    @preferred_color_scheme.setter
    def preferred_color_scheme(self, preferred_color_scheme: 'str'):
        """Sets the preferred_color_scheme of this V1GetUserResponse.


        :param preferred_color_scheme: The preferred_color_scheme of this V1GetUserResponse.  # noqa: E501
        :type: str
        """

        self._preferred_color_scheme = preferred_color_scheme

    @property
    def preferred_ide(self) -> 'str':
        """Gets the preferred_ide of this V1GetUserResponse.  # noqa: E501


        :return: The preferred_ide of this V1GetUserResponse.  # noqa: E501
        :rtype: str
        """
        return self._preferred_ide

    @preferred_ide.setter
    def preferred_ide(self, preferred_ide: 'str'):
        """Sets the preferred_ide of this V1GetUserResponse.


        :param preferred_ide: The preferred_ide of this V1GetUserResponse.  # noqa: E501
        :type: str
        """

        self._preferred_ide = preferred_ide

    @property
    def preferred_vscode_marketplace(self) -> 'str':
        """Gets the preferred_vscode_marketplace of this V1GetUserResponse.  # noqa: E501


        :return: The preferred_vscode_marketplace of this V1GetUserResponse.  # noqa: E501
        :rtype: str
        """
        return self._preferred_vscode_marketplace

    @preferred_vscode_marketplace.setter
    def preferred_vscode_marketplace(self, preferred_vscode_marketplace: 'str'):
        """Sets the preferred_vscode_marketplace of this V1GetUserResponse.


        :param preferred_vscode_marketplace: The preferred_vscode_marketplace of this V1GetUserResponse.  # noqa: E501
        :type: str
        """

        self._preferred_vscode_marketplace = preferred_vscode_marketplace

    @property
    def role(self) -> 'str':
        """Gets the role of this V1GetUserResponse.  # noqa: E501


        :return: The role of this V1GetUserResponse.  # noqa: E501
        :rtype: str
        """
        return self._role

    @role.setter
    def role(self, role: 'str'):
        """Sets the role of this V1GetUserResponse.


        :param role: The role of this V1GetUserResponse.  # noqa: E501
        :type: str
        """

        self._role = role

    @property
    def saw_create_first_project_dialog(self) -> 'bool':
        """Gets the saw_create_first_project_dialog of this V1GetUserResponse.  # noqa: E501


        :return: The saw_create_first_project_dialog of this V1GetUserResponse.  # noqa: E501
        :rtype: bool
        """
        return self._saw_create_first_project_dialog

    @saw_create_first_project_dialog.setter
    def saw_create_first_project_dialog(self, saw_create_first_project_dialog: 'bool'):
        """Sets the saw_create_first_project_dialog of this V1GetUserResponse.


        :param saw_create_first_project_dialog: The saw_create_first_project_dialog of this V1GetUserResponse.  # noqa: E501
        :type: bool
        """

        self._saw_create_first_project_dialog = saw_create_first_project_dialog

    @property
    def saw_forums_login_merge_dialog(self) -> 'bool':
        """Gets the saw_forums_login_merge_dialog of this V1GetUserResponse.  # noqa: E501


        :return: The saw_forums_login_merge_dialog of this V1GetUserResponse.  # noqa: E501
        :rtype: bool
        """
        return self._saw_forums_login_merge_dialog

    @saw_forums_login_merge_dialog.setter
    def saw_forums_login_merge_dialog(self, saw_forums_login_merge_dialog: 'bool'):
        """Sets the saw_forums_login_merge_dialog of this V1GetUserResponse.


        :param saw_forums_login_merge_dialog: The saw_forums_login_merge_dialog of this V1GetUserResponse.  # noqa: E501
        :type: bool
        """

        self._saw_forums_login_merge_dialog = saw_forums_login_merge_dialog

    @property
    def saw_free_credits_notification(self) -> 'bool':
        """Gets the saw_free_credits_notification of this V1GetUserResponse.  # noqa: E501


        :return: The saw_free_credits_notification of this V1GetUserResponse.  # noqa: E501
        :rtype: bool
        """
        return self._saw_free_credits_notification

    @saw_free_credits_notification.setter
    def saw_free_credits_notification(self, saw_free_credits_notification: 'bool'):
        """Sets the saw_free_credits_notification of this V1GetUserResponse.


        :param saw_free_credits_notification: The saw_free_credits_notification of this V1GetUserResponse.  # noqa: E501
        :type: bool
        """

        self._saw_free_credits_notification = saw_free_credits_notification

    @property
    def status(self) -> 'Externalv1UserStatus':
        """Gets the status of this V1GetUserResponse.  # noqa: E501


        :return: The status of this V1GetUserResponse.  # noqa: E501
        :rtype: Externalv1UserStatus
        """
        return self._status

    @status.setter
    def status(self, status: 'Externalv1UserStatus'):
        """Sets the status of this V1GetUserResponse.


        :param status: The status of this V1GetUserResponse.  # noqa: E501
        :type: Externalv1UserStatus
        """

        self._status = status

    @property
    def user_metadata(self) -> 'str':
        """Gets the user_metadata of this V1GetUserResponse.  # noqa: E501


        :return: The user_metadata of this V1GetUserResponse.  # noqa: E501
        :rtype: str
        """
        return self._user_metadata

    @user_metadata.setter
    def user_metadata(self, user_metadata: 'str'):
        """Sets the user_metadata of this V1GetUserResponse.


        :param user_metadata: The user_metadata of this V1GetUserResponse.  # noqa: E501
        :type: str
        """

        self._user_metadata = user_metadata

    @property
    def username(self) -> 'str':
        """Gets the username of this V1GetUserResponse.  # noqa: E501


        :return: The username of this V1GetUserResponse.  # noqa: E501
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username: 'str'):
        """Sets the username of this V1GetUserResponse.


        :param username: The username of this V1GetUserResponse.  # noqa: E501
        :type: str
        """

        self._username = username

    @property
    def waitlisted(self) -> 'bool':
        """Gets the waitlisted of this V1GetUserResponse.  # noqa: E501


        :return: The waitlisted of this V1GetUserResponse.  # noqa: E501
        :rtype: bool
        """
        return self._waitlisted

    @waitlisted.setter
    def waitlisted(self, waitlisted: 'bool'):
        """Sets the waitlisted of this V1GetUserResponse.


        :param waitlisted: The waitlisted of this V1GetUserResponse.  # noqa: E501
        :type: bool
        """

        self._waitlisted = waitlisted

    @property
    def website(self) -> 'str':
        """Gets the website of this V1GetUserResponse.  # noqa: E501


        :return: The website of this V1GetUserResponse.  # noqa: E501
        :rtype: str
        """
        return self._website

    @website.setter
    def website(self, website: 'str'):
        """Sets the website of this V1GetUserResponse.


        :param website: The website of this V1GetUserResponse.  # noqa: E501
        :type: str
        """

        self._website = website

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1GetUserResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'V1GetUserResponse') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, V1GetUserResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other: 'V1GetUserResponse') -> bool:
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401

from typing import TYPE_CHECKING

import six

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class V1BuildSpec(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'commands': 'list[str]',
        'image': 'str',
        'python_dependencies': 'V1PythonDependencyInfo',
        'working_dir': 'str'
    }

    attribute_map = {
        'commands': 'commands',
        'image': 'image',
        'python_dependencies': 'pythonDependencies',
        'working_dir': 'workingDir'
    }

    def __init__(self, commands: 'list[str]' =None, image: 'str' =None, python_dependencies: 'V1PythonDependencyInfo' =None, working_dir: 'str' =None):  # noqa: E501
        """V1BuildSpec - a model defined in Swagger"""  # noqa: E501
        self._commands = None
        self._image = None
        self._python_dependencies = None
        self._working_dir = None
        self.discriminator = None
        if commands is not None:
            self.commands = commands
        if image is not None:
            self.image = image
        if python_dependencies is not None:
            self.python_dependencies = python_dependencies
        if working_dir is not None:
            self.working_dir = working_dir

    @property
    def commands(self) -> 'list[str]':
        """Gets the commands of this V1BuildSpec.  # noqa: E501


        :return: The commands of this V1BuildSpec.  # noqa: E501
        :rtype: list[str]
        """
        return self._commands

    @commands.setter
    def commands(self, commands: 'list[str]'):
        """Sets the commands of this V1BuildSpec.


        :param commands: The commands of this V1BuildSpec.  # noqa: E501
        :type: list[str]
        """

        self._commands = commands

    @property
    def image(self) -> 'str':
        """Gets the image of this V1BuildSpec.  # noqa: E501

        A custom Docker image to run the user's workload in. This image must be publicly accessible and not hosted by DockerHub or other registries that enforce image pull rate limits.  # noqa: E501

        :return: The image of this V1BuildSpec.  # noqa: E501
        :rtype: str
        """
        return self._image

    @image.setter
    def image(self, image: 'str'):
        """Sets the image of this V1BuildSpec.

        A custom Docker image to run the user's workload in. This image must be publicly accessible and not hosted by DockerHub or other registries that enforce image pull rate limits.  # noqa: E501

        :param image: The image of this V1BuildSpec.  # noqa: E501
        :type: str
        """

        self._image = image

    @property
    def python_dependencies(self) -> 'V1PythonDependencyInfo':
        """Gets the python_dependencies of this V1BuildSpec.  # noqa: E501


        :return: The python_dependencies of this V1BuildSpec.  # noqa: E501
        :rtype: V1PythonDependencyInfo
        """
        return self._python_dependencies

    @python_dependencies.setter
    def python_dependencies(self, python_dependencies: 'V1PythonDependencyInfo'):
        """Sets the python_dependencies of this V1BuildSpec.


        :param python_dependencies: The python_dependencies of this V1BuildSpec.  # noqa: E501
        :type: V1PythonDependencyInfo
        """

        self._python_dependencies = python_dependencies

    @property
    def working_dir(self) -> 'str':
        """Gets the working_dir of this V1BuildSpec.  # noqa: E501

        Working directory for the workload. Source will be cloned here and the app work will be started from this directory.  # noqa: E501

        :return: The working_dir of this V1BuildSpec.  # noqa: E501
        :rtype: str
        """
        return self._working_dir

    @working_dir.setter
    def working_dir(self, working_dir: 'str'):
        """Sets the working_dir of this V1BuildSpec.

        Working directory for the workload. Source will be cloned here and the app work will be started from this directory.  # noqa: E501

        :param working_dir: The working_dir of this V1BuildSpec.  # noqa: E501
        :type: str
        """

        self._working_dir = working_dir

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1BuildSpec, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'V1BuildSpec') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, V1BuildSpec):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other: 'V1BuildSpec') -> bool:
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401

from typing import TYPE_CHECKING

import six

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class V1DataConnection(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'accessible': 'bool',
        'aws': 'V1AwsDataConnection',
        'gcp': 'V1GcpDataConnection',
        'id': 'str',
        'index': 'V1Index',
        'name': 'str',
        'project_id': 'str',
        'run_cmds': 'list[str]',
        'writable': 'bool'
    }

    attribute_map = {
        'accessible': 'accessible',
        'aws': 'aws',
        'gcp': 'gcp',
        'id': 'id',
        'index': 'index',
        'name': 'name',
        'project_id': 'projectId',
        'run_cmds': 'runCmds',
        'writable': 'writable'
    }

    def __init__(self, accessible: 'bool' =None, aws: 'V1AwsDataConnection' =None, gcp: 'V1GcpDataConnection' =None, id: 'str' =None, index: 'V1Index' =None, name: 'str' =None, project_id: 'str' =None, run_cmds: 'list[str]' =None, writable: 'bool' =None):  # noqa: E501
        """V1DataConnection - a model defined in Swagger"""  # noqa: E501
        self._accessible = None
        self._aws = None
        self._gcp = None
        self._id = None
        self._index = None
        self._name = None
        self._project_id = None
        self._run_cmds = None
        self._writable = None
        self.discriminator = None
        if accessible is not None:
            self.accessible = accessible
        if aws is not None:
            self.aws = aws
        if gcp is not None:
            self.gcp = gcp
        if id is not None:
            self.id = id
        if index is not None:
            self.index = index
        if name is not None:
            self.name = name
        if project_id is not None:
            self.project_id = project_id
        if run_cmds is not None:
            self.run_cmds = run_cmds
        if writable is not None:
            self.writable = writable

    @property
    def accessible(self) -> 'bool':
        """Gets the accessible of this V1DataConnection.  # noqa: E501


        :return: The accessible of this V1DataConnection.  # noqa: E501
        :rtype: bool
        """
        return self._accessible

    @accessible.setter
    def accessible(self, accessible: 'bool'):
        """Sets the accessible of this V1DataConnection.


        :param accessible: The accessible of this V1DataConnection.  # noqa: E501
        :type: bool
        """

        self._accessible = accessible

    @property
    def aws(self) -> 'V1AwsDataConnection':
        """Gets the aws of this V1DataConnection.  # noqa: E501


        :return: The aws of this V1DataConnection.  # noqa: E501
        :rtype: V1AwsDataConnection
        """
        return self._aws

    @aws.setter
    def aws(self, aws: 'V1AwsDataConnection'):
        """Sets the aws of this V1DataConnection.


        :param aws: The aws of this V1DataConnection.  # noqa: E501
        :type: V1AwsDataConnection
        """

        self._aws = aws

    @property
    def gcp(self) -> 'V1GcpDataConnection':
        """Gets the gcp of this V1DataConnection.  # noqa: E501


        :return: The gcp of this V1DataConnection.  # noqa: E501
        :rtype: V1GcpDataConnection
        """
        return self._gcp

    @gcp.setter
    def gcp(self, gcp: 'V1GcpDataConnection'):
        """Sets the gcp of this V1DataConnection.


        :param gcp: The gcp of this V1DataConnection.  # noqa: E501
        :type: V1GcpDataConnection
        """

        self._gcp = gcp

    @property
    def id(self) -> 'str':
        """Gets the id of this V1DataConnection.  # noqa: E501


        :return: The id of this V1DataConnection.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id: 'str'):
        """Sets the id of this V1DataConnection.


        :param id: The id of this V1DataConnection.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def index(self) -> 'V1Index':
        """Gets the index of this V1DataConnection.  # noqa: E501


        :return: The index of this V1DataConnection.  # noqa: E501
        :rtype: V1Index
        """
        return self._index

    @index.setter
    def index(self, index: 'V1Index'):
        """Sets the index of this V1DataConnection.


        :param index: The index of this V1DataConnection.  # noqa: E501
        :type: V1Index
        """

        self._index = index

    @property
    def name(self) -> 'str':
        """Gets the name of this V1DataConnection.  # noqa: E501


        :return: The name of this V1DataConnection.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name: 'str'):
        """Sets the name of this V1DataConnection.


        :param name: The name of this V1DataConnection.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def project_id(self) -> 'str':
        """Gets the project_id of this V1DataConnection.  # noqa: E501


        :return: The project_id of this V1DataConnection.  # noqa: E501
        :rtype: str
        """
        return self._project_id

    @project_id.setter
    def project_id(self, project_id: 'str'):
        """Sets the project_id of this V1DataConnection.


        :param project_id: The project_id of this V1DataConnection.  # noqa: E501
        :type: str
        """

        self._project_id = project_id

    @property
    def run_cmds(self) -> 'list[str]':
        """Gets the run_cmds of this V1DataConnection.  # noqa: E501


        :return: The run_cmds of this V1DataConnection.  # noqa: E501
        :rtype: list[str]
        """
        return self._run_cmds

    @run_cmds.setter
    def run_cmds(self, run_cmds: 'list[str]'):
        """Sets the run_cmds of this V1DataConnection.


        :param run_cmds: The run_cmds of this V1DataConnection.  # noqa: E501
        :type: list[str]
        """

        self._run_cmds = run_cmds

    @property
    def writable(self) -> 'bool':
        """Gets the writable of this V1DataConnection.  # noqa: E501


        :return: The writable of this V1DataConnection.  # noqa: E501
        :rtype: bool
        """
        return self._writable

    @writable.setter
    def writable(self, writable: 'bool'):
        """Sets the writable of this V1DataConnection.


        :param writable: The writable of this V1DataConnection.  # noqa: E501
        :type: bool
        """

        self._writable = writable

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1DataConnection, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'V1DataConnection') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, V1DataConnection):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other: 'V1DataConnection') -> bool:
        """Returns true if both objects are not equal"""
        return not self == other



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from lightning_cloud.openapi.api.agent_service_api import AgentServiceApi
from lightning_cloud.openapi.api.auth_service_api import AuthServiceApi
from lightning_cloud.openapi.api.billing_service_api import BillingServiceApi
from lightning_cloud.openapi.api.cloud_space_service_api import CloudSpaceServiceApi
from lightning_cloud.openapi.api.cluster_service_api import ClusterServiceApi
from lightning_cloud.openapi.api.data_connection_service_api import DataConnectionServiceApi
from lightning_cloud.openapi.api.dataset_service_api import DatasetServiceApi
from lightning_cloud.openapi.api.lightningapp_instance_service_api import LightningappInstanceServiceApi
from lightning_cloud.openapi.api.lightningapp_v2_service_api import LightningappV2ServiceApi
from lightning_cloud.openapi.api.lightningwork_service_api import LightningworkServiceApi
from lightning_cloud.openapi.api.lit_page_service_api import LitPageServiceApi
from lightning_cloud.openapi.api.models_store_api import ModelsStoreApi
from lightning_cloud.openapi.api.organizations_service_api import OrganizationsServiceApi
from lightning_cloud.openapi.api.projects_service_api import ProjectsServiceApi
from lightning_cloud.openapi.api.ssh_public_key_service_api import SSHPublicKeyServiceApi
from lightning_cloud.openapi.api.secret_service_api import SecretServiceApi
from lightning_cloud.openapi.api.slurm_jobs_user_service_api import SlurmJobsUserServiceApi
from lightning_cloud.openapi.api.studio_jobs_service_api import StudioJobsServiceApi
from lightning_cloud.openapi.api.user_service_api import UserServiceApi



# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401

from typing import TYPE_CHECKING

import six

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class IdGetBody1(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'auth': 'V1LightningAuth',
        'cluster_id': 'str',
        'desired_state': 'V1LightningappInstanceState',
        'display_name': 'str',
        'domain': 'str',
        'env': 'list[V1EnvVar]',
        'name': 'str',
        'queue_server_type': 'V1QueueServerType',
        'source_app': 'str'
    }

    attribute_map = {
        'auth': 'auth',
        'cluster_id': 'clusterId',
        'desired_state': 'desiredState',
        'display_name': 'displayName',
        'domain': 'domain',
        'env': 'env',
        'name': 'name',
        'queue_server_type': 'queueServerType',
        'source_app': 'sourceApp'
    }

    def __init__(self, auth: 'V1LightningAuth' =None, cluster_id: 'str' =None, desired_state: 'V1LightningappInstanceState' =None, display_name: 'str' =None, domain: 'str' =None, env: 'list[V1EnvVar]' =None, name: 'str' =None, queue_server_type: 'V1QueueServerType' =None, source_app: 'str' =None):  # noqa: E501
        """IdGetBody1 - a model defined in Swagger"""  # noqa: E501
        self._auth = None
        self._cluster_id = None
        self._desired_state = None
        self._display_name = None
        self._domain = None
        self._env = None
        self._name = None
        self._queue_server_type = None
        self._source_app = None
        self.discriminator = None
        if auth is not None:
            self.auth = auth
        if cluster_id is not None:
            self.cluster_id = cluster_id
        if desired_state is not None:
            self.desired_state = desired_state
        if display_name is not None:
            self.display_name = display_name
        if domain is not None:
            self.domain = domain
        if env is not None:
            self.env = env
        if name is not None:
            self.name = name
        if queue_server_type is not None:
            self.queue_server_type = queue_server_type
        if source_app is not None:
            self.source_app = source_app

    @property
    def auth(self) -> 'V1LightningAuth':
        """Gets the auth of this IdGetBody1.  # noqa: E501


        :return: The auth of this IdGetBody1.  # noqa: E501
        :rtype: V1LightningAuth
        """
        return self._auth

    @auth.setter
    def auth(self, auth: 'V1LightningAuth'):
        """Sets the auth of this IdGetBody1.


        :param auth: The auth of this IdGetBody1.  # noqa: E501
        :type: V1LightningAuth
        """

        self._auth = auth

    @property
    def cluster_id(self) -> 'str':
        """Gets the cluster_id of this IdGetBody1.  # noqa: E501


        :return: The cluster_id of this IdGetBody1.  # noqa: E501
        :rtype: str
        """
        return self._cluster_id

    @cluster_id.setter
    def cluster_id(self, cluster_id: 'str'):
        """Sets the cluster_id of this IdGetBody1.


        :param cluster_id: The cluster_id of this IdGetBody1.  # noqa: E501
        :type: str
        """

        self._cluster_id = cluster_id

    @property
    def desired_state(self) -> 'V1LightningappInstanceState':
        """Gets the desired_state of this IdGetBody1.  # noqa: E501


        :return: The desired_state of this IdGetBody1.  # noqa: E501
        :rtype: V1LightningappInstanceState
        """
        return self._desired_state

    @desired_state.setter
    def desired_state(self, desired_state: 'V1LightningappInstanceState'):
        """Sets the desired_state of this IdGetBody1.


        :param desired_state: The desired_state of this IdGetBody1.  # noqa: E501
        :type: V1LightningappInstanceState
        """

        self._desired_state = desired_state

    @property
    def display_name(self) -> 'str':
        """Gets the display_name of this IdGetBody1.  # noqa: E501


        :return: The display_name of this IdGetBody1.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name: 'str'):
        """Sets the display_name of this IdGetBody1.


        :param display_name: The display_name of this IdGetBody1.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def domain(self) -> 'str':
        """Gets the domain of this IdGetBody1.  # noqa: E501

        User-provided custom domain for the app. Will be generated if not provided.  # noqa: E501

        :return: The domain of this IdGetBody1.  # noqa: E501
        :rtype: str
        """
        return self._domain

    @domain.setter
    def domain(self, domain: 'str'):
        """Sets the domain of this IdGetBody1.

        User-provided custom domain for the app. Will be generated if not provided.  # noqa: E501

        :param domain: The domain of this IdGetBody1.  # noqa: E501
        :type: str
        """

        self._domain = domain

    @property
    def env(self) -> 'list[V1EnvVar]':
        """Gets the env of this IdGetBody1.  # noqa: E501


        :return: The env of this IdGetBody1.  # noqa: E501
        :rtype: list[V1EnvVar]
        """
        return self._env

    @env.setter
    def env(self, env: 'list[V1EnvVar]'):
        """Sets the env of this IdGetBody1.


        :param env: The env of this IdGetBody1.  # noqa: E501
        :type: list[V1EnvVar]
        """

        self._env = env

    @property
    def name(self) -> 'str':
        """Gets the name of this IdGetBody1.  # noqa: E501


        :return: The name of this IdGetBody1.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name: 'str'):
        """Sets the name of this IdGetBody1.


        :param name: The name of this IdGetBody1.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def queue_server_type(self) -> 'V1QueueServerType':
        """Gets the queue_server_type of this IdGetBody1.  # noqa: E501


        :return: The queue_server_type of this IdGetBody1.  # noqa: E501
        :rtype: V1QueueServerType
        """
        return self._queue_server_type

    @queue_server_type.setter
    def queue_server_type(self, queue_server_type: 'V1QueueServerType'):
        """Sets the queue_server_type of this IdGetBody1.


        :param queue_server_type: The queue_server_type of this IdGetBody1.  # noqa: E501
        :type: V1QueueServerType
        """

        self._queue_server_type = queue_server_type

    @property
    def source_app(self) -> 'str':
        """Gets the source_app of this IdGetBody1.  # noqa: E501


        :return: The source_app of this IdGetBody1.  # noqa: E501
        :rtype: str
        """
        return self._source_app

    @source_app.setter
    def source_app(self, source_app: 'str'):
        """Sets the source_app of this IdGetBody1.


        :param source_app: The source_app of this IdGetBody1.  # noqa: E501
        :type: str
        """

        self._source_app = source_app

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(IdGetBody1, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'IdGetBody1') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, IdGetBody1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other: 'IdGetBody1') -> bool:
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401

from typing import TYPE_CHECKING

import six

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class V1InstanceOverprovisioningSpec(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'count': 'int',
        'instance_type': 'str',
        'is_spot': 'bool',
        'resource_type': 'str',
        'volume_size': 'int'
    }

    attribute_map = {
        'count': 'count',
        'instance_type': 'instanceType',
        'is_spot': 'isSpot',
        'resource_type': 'resourceType',
        'volume_size': 'volumeSize'
    }

    def __init__(self, count: 'int' =None, instance_type: 'str' =None, is_spot: 'bool' =None, resource_type: 'str' =None, volume_size: 'int' =None):  # noqa: E501
        """V1InstanceOverprovisioningSpec - a model defined in Swagger"""  # noqa: E501
        self._count = None
        self._instance_type = None
        self._is_spot = None
        self._resource_type = None
        self._volume_size = None
        self.discriminator = None
        if count is not None:
            self.count = count
        if instance_type is not None:
            self.instance_type = instance_type
        if is_spot is not None:
            self.is_spot = is_spot
        if resource_type is not None:
            self.resource_type = resource_type
        if volume_size is not None:
            self.volume_size = volume_size

    @property
    def count(self) -> 'int':
        """Gets the count of this V1InstanceOverprovisioningSpec.  # noqa: E501


        :return: The count of this V1InstanceOverprovisioningSpec.  # noqa: E501
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count: 'int'):
        """Sets the count of this V1InstanceOverprovisioningSpec.


        :param count: The count of this V1InstanceOverprovisioningSpec.  # noqa: E501
        :type: int
        """

        self._count = count

    @property
    def instance_type(self) -> 'str':
        """Gets the instance_type of this V1InstanceOverprovisioningSpec.  # noqa: E501


        :return: The instance_type of this V1InstanceOverprovisioningSpec.  # noqa: E501
        :rtype: str
        """
        return self._instance_type

    @instance_type.setter
    def instance_type(self, instance_type: 'str'):
        """Sets the instance_type of this V1InstanceOverprovisioningSpec.


        :param instance_type: The instance_type of this V1InstanceOverprovisioningSpec.  # noqa: E501
        :type: str
        """

        self._instance_type = instance_type

    @property
    def is_spot(self) -> 'bool':
        """Gets the is_spot of this V1InstanceOverprovisioningSpec.  # noqa: E501


        :return: The is_spot of this V1InstanceOverprovisioningSpec.  # noqa: E501
        :rtype: bool
        """
        return self._is_spot

    @is_spot.setter
    def is_spot(self, is_spot: 'bool'):
        """Sets the is_spot of this V1InstanceOverprovisioningSpec.


        :param is_spot: The is_spot of this V1InstanceOverprovisioningSpec.  # noqa: E501
        :type: bool
        """

        self._is_spot = is_spot

    @property
    def resource_type(self) -> 'str':
        """Gets the resource_type of this V1InstanceOverprovisioningSpec.  # noqa: E501


        :return: The resource_type of this V1InstanceOverprovisioningSpec.  # noqa: E501
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type: 'str'):
        """Sets the resource_type of this V1InstanceOverprovisioningSpec.


        :param resource_type: The resource_type of this V1InstanceOverprovisioningSpec.  # noqa: E501
        :type: str
        """

        self._resource_type = resource_type

    @property
    def volume_size(self) -> 'int':
        """Gets the volume_size of this V1InstanceOverprovisioningSpec.  # noqa: E501


        :return: The volume_size of this V1InstanceOverprovisioningSpec.  # noqa: E501
        :rtype: int
        """
        return self._volume_size

    @volume_size.setter
    def volume_size(self, volume_size: 'int'):
        """Sets the volume_size of this V1InstanceOverprovisioningSpec.


        :param volume_size: The volume_size of this V1InstanceOverprovisioningSpec.  # noqa: E501
        :type: int
        """

        self._volume_size = volume_size

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1InstanceOverprovisioningSpec, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'V1InstanceOverprovisioningSpec') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, V1InstanceOverprovisioningSpec):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other: 'V1InstanceOverprovisioningSpec') -> bool:
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    external/v1/auth_service.proto

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: version not set
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git

    NOTE
    ----
    standard swagger-codegen-cli for this python client has been modified
    by custom templates. The purpose of these templates is to include
    typing information in the API and Model code. Please refer to the
    main grid repository for more info
"""

import pprint
import re  # noqa: F401

from typing import TYPE_CHECKING

import six

if TYPE_CHECKING:
    from datetime import datetime
    from lightning_cloud.openapi.models import *

class V1LitPage(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'children': 'list[V1LitPage]',
        'content': 'str',
        'created_at': 'datetime',
        'creator_id': 'str',
        'id': 'str',
        'order': 'int',
        'parent_id': 'str',
        'resource_id': 'str',
        'resource_type': 'str',
        'type': 'V1LitPageType',
        'updated_at': 'datetime'
    }

    attribute_map = {
        'children': 'children',
        'content': 'content',
        'created_at': 'createdAt',
        'creator_id': 'creatorId',
        'id': 'id',
        'order': 'order',
        'parent_id': 'parentId',
        'resource_id': 'resourceId',
        'resource_type': 'resourceType',
        'type': 'type',
        'updated_at': 'updatedAt'
    }

    def __init__(self, children: 'list[V1LitPage]' =None, content: 'str' =None, created_at: 'datetime' =None, creator_id: 'str' =None, id: 'str' =None, order: 'int' =None, parent_id: 'str' =None, resource_id: 'str' =None, resource_type: 'str' =None, type: 'V1LitPageType' =None, updated_at: 'datetime' =None):  # noqa: E501
        """V1LitPage - a model defined in Swagger"""  # noqa: E501
        self._children = None
        self._content = None
        self._created_at = None
        self._creator_id = None
        self._id = None
        self._order = None
        self._parent_id = None
        self._resource_id = None
        self._resource_type = None
        self._type = None
        self._updated_at = None
        self.discriminator = None
        if children is not None:
            self.children = children
        if content is not None:
            self.content = content
        if created_at is not None:
            self.created_at = created_at
        if creator_id is not None:
            self.creator_id = creator_id
        if id is not None:
            self.id = id
        if order is not None:
            self.order = order
        if parent_id is not None:
            self.parent_id = parent_id
        if resource_id is not None:
            self.resource_id = resource_id
        if resource_type is not None:
            self.resource_type = resource_type
        if type is not None:
            self.type = type
        if updated_at is not None:
            self.updated_at = updated_at

    @property
    def children(self) -> 'list[V1LitPage]':
        """Gets the children of this V1LitPage.  # noqa: E501


        :return: The children of this V1LitPage.  # noqa: E501
        :rtype: list[V1LitPage]
        """
        return self._children

    @children.setter
    def children(self, children: 'list[V1LitPage]'):
        """Sets the children of this V1LitPage.


        :param children: The children of this V1LitPage.  # noqa: E501
        :type: list[V1LitPage]
        """

        self._children = children

    @property
    def content(self) -> 'str':
        """Gets the content of this V1LitPage.  # noqa: E501


        :return: The content of this V1LitPage.  # noqa: E501
        :rtype: str
        """
        return self._content

    @content.setter
    def content(self, content: 'str'):
        """Sets the content of this V1LitPage.


        :param content: The content of this V1LitPage.  # noqa: E501
        :type: str
        """

        self._content = content

    @property
    def created_at(self) -> 'datetime':
        """Gets the created_at of this V1LitPage.  # noqa: E501


        :return: The created_at of this V1LitPage.  # noqa: E501
        :rtype: datetime
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at: 'datetime'):
        """Sets the created_at of this V1LitPage.


        :param created_at: The created_at of this V1LitPage.  # noqa: E501
        :type: datetime
        """

        self._created_at = created_at

    @property
    def creator_id(self) -> 'str':
        """Gets the creator_id of this V1LitPage.  # noqa: E501


        :return: The creator_id of this V1LitPage.  # noqa: E501
        :rtype: str
        """
        return self._creator_id

    @creator_id.setter
    def creator_id(self, creator_id: 'str'):
        """Sets the creator_id of this V1LitPage.


        :param creator_id: The creator_id of this V1LitPage.  # noqa: E501
        :type: str
        """

        self._creator_id = creator_id

    @property
    def id(self) -> 'str':
        """Gets the id of this V1LitPage.  # noqa: E501


        :return: The id of this V1LitPage.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id: 'str'):
        """Sets the id of this V1LitPage.


        :param id: The id of this V1LitPage.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def order(self) -> 'int':
        """Gets the order of this V1LitPage.  # noqa: E501


        :return: The order of this V1LitPage.  # noqa: E501
        :rtype: int
        """
        return self._order

    @order.setter
    def order(self, order: 'int'):
        """Sets the order of this V1LitPage.


        :param order: The order of this V1LitPage.  # noqa: E501
        :type: int
        """

        self._order = order

    @property
    def parent_id(self) -> 'str':
        """Gets the parent_id of this V1LitPage.  # noqa: E501


        :return: The parent_id of this V1LitPage.  # noqa: E501
        :rtype: str
        """
        return self._parent_id

    @parent_id.setter
    def parent_id(self, parent_id: 'str'):
        """Sets the parent_id of this V1LitPage.


        :param parent_id: The parent_id of this V1LitPage.  # noqa: E501
        :type: str
        """

        self._parent_id = parent_id

    @property
    def resource_id(self) -> 'str':
        """Gets the resource_id of this V1LitPage.  # noqa: E501


        :return: The resource_id of this V1LitPage.  # noqa: E501
        :rtype: str
        """
        return self._resource_id

    @resource_id.setter
    def resource_id(self, resource_id: 'str'):
        """Sets the resource_id of this V1LitPage.


        :param resource_id: The resource_id of this V1LitPage.  # noqa: E501
        :type: str
        """

        self._resource_id = resource_id

    @property
    def resource_type(self) -> 'str':
        """Gets the resource_type of this V1LitPage.  # noqa: E501


        :return: The resource_type of this V1LitPage.  # noqa: E501
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type: 'str'):
        """Sets the resource_type of this V1LitPage.


        :param resource_type: The resource_type of this V1LitPage.  # noqa: E501
        :type: str
        """

        self._resource_type = resource_type

    @property
    def type(self) -> 'V1LitPageType':
        """Gets the type of this V1LitPage.  # noqa: E501


        :return: The type of this V1LitPage.  # noqa: E501
        :rtype: V1LitPageType
        """
        return self._type

    @type.setter
    def type(self, type: 'V1LitPageType'):
        """Sets the type of this V1LitPage.


        :param type: The type of this V1LitPage.  # noqa: E501
        :type: V1LitPageType
        """

        self._type = type

    @property
    def updated_at(self) -> 'datetime':
        """Gets the updated_at of this V1LitPage.  # noqa: E501


        :return: The updated_at of this V1LitPage.  # noqa: E501
        :rtype: datetime
        """
        return self._updated_at

    @updated_at.setter
    def updated_at(self, updated_at: 'datetime'):
        """Sets the updated_at of this V1LitPage.


        :param updated_at: The updated_at of this V1LitPage.  # noqa: E501
        :type: datetime
        """

        self._updated_at = updated_at

    def to_dict(self) -> dict:
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(V1LitPage, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self) -> str:
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self) -> str:
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other: 'V1LitPage') -> bool:
        """Returns true if both objects are equal"""
        if not isinstance(other, V1LitPage):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other: 'V1LitPage') -> bool:
        """Returns true if both objects are not equal"""
        return not self == other
